<?php

    /**
     * For full documentation, please visit: http://docs.reduxframework.com/
     * For a more extensive sample-config file, you may look at:
     * https://github.com/reduxframework/redux-framework/blob/master/sample/sample-config.php
     */

    if ( ! class_exists( 'Redux' ) ) {
        return;
    }

    // This is your option name where all the Redux data is stored.
    $opt_name = "startos_option";

    /**
     * ---> SET ARGUMENTS
     * All the possible arguments for Redux.
     * For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments
     * */

    $theme = wp_get_theme(); // For use with some settings. Not necessary.

    $args = array(
        'opt_name' => 'startos_option',
        'use_cdn' => TRUE,
        'display_name'     => $theme->get('Name'),
        'display_version'  => $theme->get('Version'),
        'page_title' => 'Startos Options',
        'update_notice' => FALSE,
        'admin_bar' => TRUE,
        'menu_type' => 'menu',
        'menu_title' => 'Startos Options',
        'allow_sub_menu' => TRUE,
        'page_parent_post_type' => 'your_post_type',
        'customizer' => TRUE,
        'dev_mode'   => false,
        'default_mark' => '*',
        'hints' => array(
            'icon_position' => 'right',
            'icon_color' => 'lightgray',
            'icon_size' => 'normal',
            'tip_style' => array(
                'color' => 'light',
            ),
            'tip_position' => array(
                'my' => 'top left',
                'at' => 'bottom right',
            ),
            'tip_effect' => array(
                'show' => array(
                    'duration' => '500',
                    'event' => 'mouseover',
                ),
                'hide' => array(
                    'duration' => '500',
                    'event' => 'mouseleave unfocus',
                ),
            ),
        ),
        'output' => TRUE,
        'output_tag' => TRUE,
        'settings_api' => TRUE,
        'cdn_check_time' => '1440',
        'compiler' => TRUE,
        'page_permissions' => 'manage_options',
        'save_defaults' => TRUE,
        'show_import_export' => TRUE,
        'database' => 'options',
        'transient_time' => '3600',
        'network_sites' => TRUE,
    );

    Redux::setArgs( $opt_name, $args );

    /*
     * ---> END ARGUMENTS
     */

    /*
     * ---> START HELP TABS
     */

    $tabs = array(
        array(
            'id'      => 'redux-help-tab-1',
            'title'   => esc_html__( 'Theme Information 1', 'startos' ),
            'content' => esc_html__( 'This is the tab content, HTML is allowed.', 'startos' )
        ),
        array(
            'id'      => 'redux-help-tab-2',
            'title'   => esc_html__( 'Theme Information 2', 'startos' ),
            'content' => esc_html__( 'This is the tab content, HTML is allowed.', 'startos' )
        )
    );
    Redux::setHelpTab( $opt_name, $tabs );

    // Set the help sidebar
    $content = esc_html__( 'This is the sidebar content, HTML is allowed.', 'startos' );
    Redux::setHelpSidebar( $opt_name, $content );


    /*
     * <--- END HELP TABS
     */


    /*
     *
     * ---> START SECTIONS
     *
     */

    // ACTUAL DECLARATION OF SECTIONS
    Redux::setSection( $opt_name, array(

        'icon' => ' el-icon-picture',

        'title' => __('Logo & Favicon Settings', 'startos'),

        'fields' => array(

            array(

                'id' => 'favicon',

                'type' => 'media',

                'url' => true,

                'title' => __('Custom Favicon', 'startos'),

                'compiler' => 'true',            

                'desc' => __('Upload your Favicon.', 'startos'),

                'subtitle' => __('', 'startos'),

                'default' => array('url' => get_template_directory_uri().'/img/favicon.png'),

            ),
            array(
                'id' => 'logo',
                'type' => 'media',
                'url' => true,
                'title' => __('Logo', 'startos'),
                'compiler' => 'true',
                'desc' => __('logo.', 'startos'),
                'subtitle' => __('', 'startos'),
               'default' => array('url' => get_template_directory_uri().'/img/logo.png'),                     
            ),      

        )

    ) ); 



    Redux::setSection( $opt_name, array(

        'icon' => 'el-icon-blogger',

        'title' => __('Blog Settings', 'startos'),

        'fields' => array(
            array(
                'id' => 'bg_allpage',
                'type' => 'media',
                'url' => true,
                'title' => __('Background Header', 'startos'),
                'compiler' => 'true',
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'desc' => __('.', 'startos'),
                'subtitle' => __('', 'startos'),
               'default' => array('url' => get_template_directory_uri().'/img/blogsubheader.jpg'),                     
            ), 
            array(

                'id' => 'blog_title',

                'type' => 'text',

                'title' => __('The Blog Title', 'startos'),

                'subtitle' => __('Title Blog', 'startos'),

                'desc' => __('', 'startos'),

                'default' => 'Blog'

            ),

            array(

                'id' => 'blog_excerpt',

                'type' => 'text',

                'title' => __('Blog custom excerpt leng', 'startos'),

                'subtitle' => __('Input Blog custom excerpt leng', 'startos'),

                'desc' => __('', 'startos'),

                'default' => '50'

            ),

         )

   ) );        

    Redux::setSection( $opt_name, array(
        'icon' => ' el-icon-credit-card',
        'title' => __('Footer Settings', 'startos'),
        'fields' => array(  
            
            array(
                'id' => 'footer_text',
                'type' => 'editor',
                'title' => __('Footer Text', 'startos'),
                'subtitle' => __('Copyright Text', 'startos'),
                'default' => '© 2018 Startos • All Rights Reserved',
            ),
            array(
                'id' => 'facebook',
                'type' => 'text',
                'title' => __('Facebook Url', 'startos'),
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'default' => 'https://www.facebook.com/',
            ),
            array(
                'id' => 'google',
                'type' => 'text',
                'title' => __('Google+ Url', 'startos'),
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'default' => '',
            ),
            array(
                'id' => 'twitter',
                'type' => 'text',
                'title' => __('Twitter Url', 'startos'),
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'default' => 'https://twitter.com/',
            ),
            array(
                'id' => 'github',
                'type' => 'text',
                'title' => __('Github Url', 'startos'),
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'default' => ''
            ),
            array(
                'id' => 'youtube',
                'type' => 'text',
                'title' => __('Youtube Url', 'startos'),
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'default' => '',
            ),
            array(
                'id' => 'linkedin',
                'type' => 'text',
                'title' => __('Linkedin Url', 'startos'),
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'default' => 'https://www.linkedin.com/',
            ),
            array(
                'id' => 'dribbble',
                'type' => 'text',
                'title' => __('Dribbble Url', 'startos'),
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'default' => '',
            ),
            array(
                'id' => 'behance',
                'type' => 'text',
                'title' => __('Behance Url', 'startos'),
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'default' => ''
            ),
            array(
                'id' => 'instagram',
                'type' => 'text',
                'title' => __('Instagram Url', 'startos'),
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'default' => ''
            ),
            array(
                'id' => 'skype',
                'type' => 'text',
                'title' => __('Skype Url', 'startos'),
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'default' => ''
            ),      
        )
   ) ); 

    Redux::setSection( $opt_name, array(

        'icon' => 'el-icon-website',

        'title' => __('Styling Options', 'startos'),

        'fields' => array(
            array(
                'id' => 'version_type',
                'type' => 'select',
                'title' => __('Theme Version', 'startos'),
                'subtitle' => __('Dark or White', 'startos'),
                'desc' => __('', 'startos'),
                'options'  => array(
                    'dark' => 'Dark Version',
                    'light' => 'Light Version',
                ),
                'default' => 'light',
            ),

            array(
                'id' => 'main-color',
                'type' => 'color',
                'title' => __('Theme Main Color', 'startos'),
                'subtitle' => __('Pick the main color for the theme (default: ##0097d3).', 'startos'),
                'default' => '#0097d3',
                'validate' => 'color',
            ),

            array(
                'id' => 'background_header',
                'type' => 'color',
                'title' => __('Header Background Color', 'startos'),
                'subtitle' => __('Pick a background color for the header (default: Transparent).', 'startos'),
                'default' => 'transparent',
                'validate' => 'color',
            ),

            array(
                'id' => 'background_header_scroll',
                'type' => 'color',
                'title' => __('Header Scroll Background Color', 'startos'),
                'subtitle' => __('Pick a background color for the header scroll (default: #101010).', 'startos'),
                'default' => '#101010',
                'validate' => 'color',
            ),

            array(
                'id' => 'color_header',
                'type' => 'color',
                'title' => __('Text Color Header', 'startos'),
                'subtitle' => __('Pick a  color for the header (default: #ffffff).', 'startos'),
                'default' => '#ffffff',
                'validate' => 'color',
            ),  
            
            array(
                'id' => 'background_footer',
                'type' => 'color',
                'title' => __('Footer Background Color', 'startos'),
                'subtitle' => __('Pick a background color for the footer (default: #212737).', 'startos'),
                'default' => '#212737',
                'validate' => 'color',
            ),

            array(
                'id' => 'color_footer',
                'type' => 'color',
                'title' => __('Text Color Footer', 'startos'),
                'subtitle' => __('Pick a  color for the footer (default: #ffffff).', 'startos'),
                'default' => '#ffffff',
                'validate' => 'color',
            ),                                  

            array(

                'id' => 'body-font2',

                'type' => 'typography',

                'output' => array('body'),

                'title' => __('Body Font', 'startos'),

                'subtitle' => __('Specify the body font properties.', 'startos'),

                'google' => true,

                'default' => array(

                    'color' => '',

                    'font-size' => '',

                    'line-height' => '',

                    'font-family' => '',

                    'font-weight' => ''

                ),

            ),

             array(

                'id' => 'custom-css',

                'type' => 'ace_editor',

                'title' => __('CSS Code', 'startos'),

                'subtitle' => __('Paste your CSS code here.', 'startos'),

                'mode' => 'css',

                'theme' => 'monokai',

                'desc' => 'Possible modes can be found at <a href="http://ace.c9.io" target="_blank">http://ace.c9.io/</a>.',

                'default' => "#header{\nmargin: 0 auto;\n}"

            ),

        )

    ) );  

    /*
     * <--- END SECTIONS
     */